#!/bin/sh

#Check if run as root
if [ "$(id -u)" != "0" ]; then
    echo "This script must be run as root"
    exit 1
fi

#Set in var if the service is already installed
AUDIRVANA_SERVICE_INSTALLED=0
if [ -e /etc/systemd/system/audirvanaStudio.service ]; then
    AUDIRVANA_SERVICE_INSTALLED=1
fi

case $1 in
    enable)
    #if already installed and enabled, do nothing
    if [ $AUDIRVANA_SERVICE_INSTALLED -eq 1 ]; then
        echo "The audirvanaStudio service is already installed, use $0 disable to remove it"
        exit 1
    fi
    #If username is specified, use it, otherwise use audirvana
    if [ -z "$2" ]; then
        AUDIRVANA_USER=audirvana
        #Create audirvana user if it doesn't exist

        if ! id -u audirvana > /dev/null 2>&1; then
            echo "Creating audirvana user"
            if ! /usr/sbin/useradd -p "*" --user-group --create-home --shell /bin/false audirvana > /dev/null 2>&1; then
                echo "Failed to create audirvana user"
                exit 1
            fi
        fi
    else
        AUDIRVANA_USER=$2
        if ! id -u $2 > /dev/null 2>&1; then
            echo "User $2 does not exist"
            exit 1
        fi
    fi
    echo "The audirvanaStudio service will run as user $AUDIRVANA_USER"

    echo "Installing audirvanaStudio service"

    #Copy service file
    /bin/cp -f /opt/audirvana/studio/share/etc/audirvanaStudio.service /etc/systemd/system/audirvanaStudio.service
    chown root:root /etc/systemd/system/audirvanaStudio.service
    chmod 644 /etc/systemd/system/audirvanaStudio.service

    #Replace audirvana user in service file, if is it not audirvana
    if [ "$AUDIRVANA_USER" != "audirvana" ]; then
        sed -i "s/User=audirvana/User=$AUDIRVANA_USER/g" /etc/systemd/system/audirvanaStudio.service
    fi

    #refresh systemd daemons list
    /usr/bin/systemctl daemon-reload > /dev/null 2>&1

    #enable service
    /usr/bin/systemctl enable audirvanaStudio > /dev/null 2>&1
    ;;

    disable)
    #if not installed, do nothing
    if [ $AUDIRVANA_SERVICE_INSTALLED -eq 0 ]; then
        echo "The audirvanaStudio service is not installed"
        exit 1
    fi
    echo "Removing audirvanaStudio service"

    #Stop any already running service
    /usr/bin/systemctl disable audirvanaStudio > /dev/null 2>&1
    /usr/bin/systemctl stop audirvanaStudio > /dev/null 2>&1

    #remove service file
    /bin/rm -f /etc/systemd/system/audirvanaStudio.service

    #refresh systemd daemons list
    /usr/bin/systemctl daemon-reload > /dev/null 2>&1
    ;;

    start)
    #if not installed, do nothing
    if [ $AUDIRVANA_SERVICE_INSTALLED -eq 0 ]; then
        echo "The audirvanaStudio service is not installed, use $0 enable to install it"
        exit 1
    fi
    echo "Starting audirvanaStudio service"
    /usr/bin/systemctl start audirvanaStudio > /dev/null 2>&1
    ;;

    stop)
    #if not installed, do nothing
    if [ $AUDIRVANA_SERVICE_INSTALLED -eq 0 ]; then
        echo "The audirvanaStudio service is not installed, use $0 enable to install it"
        exit 1
    fi
    echo "Stopping audirvanaStudio service"
    /usr/bin/systemctl stop audirvanaStudio > /dev/null 2>&1
    ;;

    status)
    #if not installed, do nothing
    if [ $AUDIRVANA_SERVICE_INSTALLED -eq 0 ]; then
        echo "The audirvanaStudio service is not installed"
        exit 1
    fi
    /usr/bin/systemctl status audirvanaStudio
    ;;

    *)
    echo "Usage: $0 {enable|disable|start|stop|status} [username]"
    echo "enable:  install audirvanaStudio service and enable it for autostart at system boot"
    echo "         if username is specified, the service will run as this user, otherwise the user audirvana will be created and used"
    echo "disable: remove audirvanaStudio service"
    echo "start:   start audirvanaStudio service"
    echo "stop:    stop audirvanaStudio service"
    echo "status:  show audirvanaStudio service status"
    exit 1
    ;;
esac

exit 0


    
